@@ -56,7 +56,6 @@ _SUPPORTED_USERS['kolla']='kolla 42400 42400'
 _SUPPORTED_USERS['libvirt']='libvirt 42473 42473'
 _SUPPORTED_USERS['manila']='manila 42429 42429 /var/lib/manila kolla'
 _SUPPORTED_USERS['memcached']='memcached 42457 42457 /run/memcache kolla'
-_SUPPORTED_USERS['mistral']='mistral 42430 42430 /var/lib/mistral kolla'
 _SUPPORTED_USERS['mysql']='mysql 42434 42434 /var/lib/mysql kolla'
 _SUPPORTED_USERS['neutron']='neutron 42435 42435 /var/lib/neutron kolla'
 _SUPPORTED_USERS['nfast']='nfast 42481 42481'
@@ -70,7 +69,8 @@ _SUPPORTED_USERS['qemu']='qemu 107 107'
 _SUPPORTED_USERS['rabbitmq']='rabbitmq 42439 42439 /var/lib/rabbitmq kolla'
 _SUPPORTED_USERS['redis']='redis 42460 42460 /run/redis kolla'
 _SUPPORTED_USERS['swift']='swift 42445 42445 /var/lib/swift kolla'
-_SUPPORTED_USERS['zaqar']='zaqar 42452 42452 /var/lib/zaqar kolla'
+_SUPPORTED_USERS['tempest']='tempest 42480 42480 /var/lib/tempest kolla'
+_SUPPORTED_USERS['tss']='tss 42485 42485 /var/lib/tpm kolla'
 
 for _USER_TO_CREATE in $_USERS_TO_CREATE; do
     # Initialize computed args
