@@ -13,8 +13,7 @@
 #   under the License.
 #
 
-
-import mock
+from unittest import mock
 
 from tripleo_common.image.base import BaseImageManager
 from tripleo_common.image.exception import ImageSpecificationException
@@ -26,7 +25,7 @@ class TestBaseImageManager(testbase.TestCase):
     def setUp(self):
         super(TestBaseImageManager, self).setUp()
 
-    @mock.patch('yaml.load', autospec=True)
+    @mock.patch('yaml.safe_load', autospec=True)
     @mock.patch('os.path.isfile', autospec=True)
     def test_load_config_files(self, mock_os_path_isfile, mock_yaml_load):
         mock_yaml_load.return_value = fakes.create_disk_images()
@@ -38,7 +37,7 @@ class TestBaseImageManager(testbase.TestCase):
 
         with mock.patch('six.moves.builtins.open', mock_open_context):
             base_manager = BaseImageManager(['yamlfile'])
-            disk_images = base_manager.load_config_files()
+            disk_images = base_manager.load_config_files('disk_images')
 
         mock_yaml_load.assert_called_once_with("YAML")
         self.assertEqual([{
@@ -51,9 +50,12 @@ class TestBaseImageManager(testbase.TestCase):
 
     def test_load_config_files_not_found(self):
         base_manager = BaseImageManager(['file/does/not/exist'])
-        self.assertRaises(IOError, base_manager.load_config_files)
+        self.assertRaises(IOError, base_manager.load_config_files,
+                          'disk_images')
 
-    @mock.patch('yaml.load', autospec=True)
+    @mock.patch('tripleo_common.image.base.BaseImageManager.APPEND_ATTRIBUTES',
+                ['elements', 'options', 'packages', 'environment'])
+    @mock.patch('yaml.safe_load', autospec=True)
     @mock.patch('os.path.isfile', autospec=True)
     def test_load_config_files_multiple_files(self, mock_os_path_isfile,
                                               mock_yaml_load):
@@ -63,7 +65,8 @@ class TestBaseImageManager(testbase.TestCase):
                 'imagename': 'overcloud',
                 'distro': 'some_awesome_distro',
                 'type': 'qcow2',
-                'elements': ['image_element']
+                'elements': ['image_element'],
+                'environment': {'test_env': '1'},
             }]},
             {
             'disk_images': [{
@@ -71,6 +74,7 @@ class TestBaseImageManager(testbase.TestCase):
                 'elements': ['another_image_element'],
                 'packages': ['a_package'],
                 'otherkey': 'some_other_key',
+                'environment': {'test_env2': '0'},
             }]}]
 
         mock_os_path_isfile.return_value = True
@@ -80,7 +84,7 @@ class TestBaseImageManager(testbase.TestCase):
 
         with mock.patch('six.moves.builtins.open', mock_open_context):
             base_manager = BaseImageManager(['yamlfile1', 'yamlfile2'])
-            disk_images = base_manager.load_config_files()
+            disk_images = base_manager.load_config_files('disk_images')
 
         self.assertEqual(2, mock_yaml_load.call_count)
         self.assertEqual([{
@@ -91,9 +95,10 @@ class TestBaseImageManager(testbase.TestCase):
             'elements': ['image_element', 'another_image_element'],
             'packages': ['a_package'],
             'otherkey': 'some_other_key',
+            'environment': {'test_env': '1', 'test_env2': '0'},
         }], disk_images)
 
-    @mock.patch('yaml.load', autospec=True)
+    @mock.patch('yaml.safe_load', autospec=True)
     @mock.patch('os.path.isfile', autospec=True)
     def test_load_config_files_missing_image_name(self, mock_os_path_isfile,
                                                   mock_yaml_load):
@@ -117,4 +122,45 @@ class TestBaseImageManager(testbase.TestCase):
         with mock.patch('six.moves.builtins.open', mock_open_context):
             base_manager = BaseImageManager(['yamlfile'])
             self.assertRaises(ImageSpecificationException,
-                              base_manager.load_config_files)
+                              base_manager.load_config_files, 'disk_images')
+
+    @mock.patch('yaml.safe_load', autospec=True)
+    @mock.patch('os.path.isfile', autospec=True)
+    def test_load_config_files_single_image(self, mock_os_path_isfile,
+                                            mock_yaml_load):
+        mock_yaml_load.side_effect = [{
+            'disk_images': [
+                {
+                    'arch': 'amd64',
+                    'imagename': 'overcloud',
+                    'distro': 'some_awesome_distro',
+                    'type': 'qcow2',
+                    'elements': ['image_element']
+                },
+                {
+                    'arch': 'amd64',
+                    'imagename': 'not-overcloud',
+                    'distro': 'some_other_distro',
+                    'type': 'qcow2',
+                    'elements': ['other_element']
+                }
+            ]}]
+
+        mock_os_path_isfile.return_value = True
+
+        mock_open_context = mock.mock_open()
+        mock_open_context().read.return_value = "YAML"
+
+        with mock.patch('six.moves.builtins.open', mock_open_context):
+            base_manager = BaseImageManager(['yamlfile1'],
+                                            images=['not-overcloud'])
+            disk_images = base_manager.load_config_files('disk_images')
+
+        self.assertEqual(1, mock_yaml_load.call_count)
+        self.assertEqual([{
+            'arch': 'amd64',
+            'distro': 'some_other_distro',
+            'imagename': 'not-overcloud',
+            'type': 'qcow2',
+            'elements': ['other_element'],
+        }], disk_images)
