@@ -34,7 +34,6 @@ parameter_defaults:
   OvercloudControlFlavor: yummy
 passwords:
   AdminPassword: aaaa
-  ZaqarPassword: zzzz
 """
 
 USER_ENV_CONTENTS = """
@@ -75,12 +74,10 @@ CAPABILITIES_DICT = {
 
 _EXISTING_PASSWORDS = {
     'PlacementPassword': 'VFJeqBKbatYhQm9jja67hufft',
-    'MistralPassword': 'VFJeqBKbatYhQm9jja67hufft',
     'BarbicanPassword': 'MGGQBtgKT7FnywvkcdMwE9nhx',
     'BarbicanSimpleCryptoKek': 'dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
     'AdminPassword': 'jFmY8FTpvtF2e4d4ReXvmUP8k',
     'CeilometerMeteringSecret': 'CbHTGK4md4Cc8P8ZyzTns6wry',
-    'ZaqarPassword': 'bbFgCTFbAH8vf9n3xvZCP8aMR',
     'NovaPassword': '7dZATgVPwD7Ergs9kTTDMCr7F',
     'MysqlRootPassword': 'VqJYpEdKks',
     'RabbitCookie': 'BqJYpEdKksAqJYpEdKks',
@@ -450,11 +447,9 @@ class PlanTest(base.TestCase):
         }
         mock_orchestration.resources.get.return_value = mock_resource
         rotate_list = [
-            'MistralPassword',
             'BarbicanPassword',
             'AdminPassword',
             'CeilometerMeteringSecret',
-            'ZaqarPassword',
             'NovaPassword',
             'MysqlRootPassword'
         ]
